@@ -51,13 +51,14 @@ class AccountSettings:
 
     Parameters
     ----------
-    requests : ro_py.utilities.requests.Requests
-        Requests object to use for API requests.
+    cso : ro_py.client.ClientSharedObject
+        ClientSharedObject.
     """
-    def __init__(self, requests):
-        self.requests = requests
+    def __init__(self, cso):
+        self.cso = cso
+        self.requests = cso.requests
 
-    def get_privacy_setting(self, privacy_setting):
+    async def get_privacy_setting(self, privacy_setting):
         """
         Gets the value of a privacy setting.
         """
@@ -79,5 +80,5 @@ class AccountSettings:
             "privateMessagePrivacy"
         ][privacy_setting]
         privacy_endpoint = endpoint + "v1/" + privacy_endpoint
-        privacy_req = self.requests.get(privacy_endpoint)
+        privacy_req = await self.requests.get(privacy_endpoint)
         return privacy_req.json()[privacy_key]
