@@ -1,9 +1,29 @@
-from ro_py.utilities.errors import ApiError
-from ro_py.utilities.cache import Cache
+from ro_py.utilities.errors import ApiError, c_errors
 from ro_py.captcha import CaptchaMetadata
 from json.decoder import JSONDecodeError
-import requests_async
 import requests
+import httpx
+
+
+class AsyncSession(httpx.AsyncClient):
+    """
+    This serves no purpose other than to get around an annoying HTTPX warning.
+    """
+    def __init__(self):
+        super().__init__()
+
+    def __del__(self):
+        pass
+
+
+def status_code_error(status_code):
+    """
+    Converts a status code to the proper exception.
+    """
+    if str(status_code) in c_errors:
+        return c_errors[str(status_code)]
+    else:
+        return ApiError
 
 
 class Requests:
@@ -11,10 +31,8 @@ class Requests:
     This wrapper functions similarly to requests_async.Session, but made specifically for Roblox.
     """
     def __init__(self):
-        self.session = requests_async.Session()
+        self.session = AsyncSession()
         """Session to use for requests."""
-        self.cache = Cache()
-        """Cache object to use for object storage."""
 
         """
         Thank you @nsg for letting me know about this!
@@ -53,7 +71,7 @@ class Requests:
         if quickreturn:
             return get_request
 
-        raise ApiError(f"[{str(get_request.status_code)}] {get_request_error[0]['message']}")
+        raise status_code_error(get_request.status_code)(f"[{get_request.status_code}] {get_request_error[0]['message']}")
 
     def back_post(self, *args, **kwargs):
         kwargs["cookies"] = kwargs.pop("cookies", self.session.cookies)
@@ -100,7 +118,7 @@ class Requests:
         if quickreturn:
             return post_request
 
-        raise ApiError(f"[{str(post_request.status_code)}] {post_request_error[0]['message']}")
+        raise status_code_error(post_request.status_code)(f"[{post_request.status_code}] {post_request_error[0]['message']}")
 
     async def patch(self, *args, **kwargs):
         """
@@ -124,7 +142,7 @@ class Requests:
         else:
             return patch_request
 
-        raise ApiError(f"[{str(patch_request.status_code)}] {patch_request_error[0]['message']}")
+        raise status_code_error(patch_request.status_code)(f"[{patch_request.status_code}] {patch_request_error[0]['message']}")
 
     async def delete(self, *args, **kwargs):
         """
@@ -148,7 +166,7 @@ class Requests:
         else:
             return delete_request
 
-        raise ApiError(f"[{str(delete_request.status_code)}] {delete_request_error[0]['message']}")
+        raise status_code_error(delete_request.status_code)(f"[{delete_request.status_code}] {delete_request_error[0]['message']}")
 
     async def get_captcha_metadata(self):
         captcha_meta_req = await self.get(
